@@ -18,6 +18,7 @@ from typing import Union, List, Tuple
 from pathlib import Path
 
 import music21 as m21
+import converter21
 
 from musicdiff.m21utils import M21Utils
 from musicdiff.m21utils import DetailLevel
@@ -81,6 +82,10 @@ def diff(score1: Union[str, Path, m21.stream.Score],
     Returns:
         int: The number of differences found (0 means the scores were identical, None means the diff failed)
     '''
+    # Use the new Humdrum/MEI importers from converter21 in place of the ones in music21...
+    # Comment out this line to go back to music21's built-in Humdrum/MEI importers.
+    converter21.register()
+
     badArg1: bool = False
     badArg2: bool = False
 
