@@ -83,6 +83,16 @@ class AnnNote:
             self.note_head = type_number
         # dots
         self.dots = general_note.duration.dots
+        # graceness
+        if isinstance(general_note.duration, m21.duration.AppoggiaturaDuration):
+            self.graceType = 'acc'
+            self.graceSlash = general_note.duration.slash
+        elif isinstance(general_note.duration, m21.duration.GraceDuration):
+            self.graceType = 'nonacc'
+            self.graceSlash = general_note.duration.slash
+        else:
+            self.graceType = ''
+            self.graceSlash = False
         # articulations
         self.articulations = [a.name for a in general_note.articulations]
         if self.articulations:
@@ -161,6 +171,10 @@ class AnnNote:
         string += str(self.note_head)  # add for notehead
         for _ in range(self.dots):  # add for dots
             string += "*"
+        if self.graceType:
+            string += self.graceType
+            if self.graceSlash:
+                string += '/'
         if len(self.beamings) > 0:  # add for beaming
             string += "B"
             for b in self.beamings:
@@ -263,7 +277,9 @@ class AnnExtra:
         self.extra = extra.id
         self.offset: float
         self.duration: float
+        self.numNotes: int = 1
         if isinstance(extra, m21.spanner.Spanner):
+            self.numNotes = len(extra)
             firstNote: m21.note.GeneralNote = extra.getFirst()
             lastNote: m21.note.GeneralNote = extra.getLast()
             self.offset = float(firstNote.getOffsetInHierarchy(measure))
@@ -301,6 +317,8 @@ class AnnExtra:
             str: the compared representation of the AnnExtra. Does not consider music21 id.
         """
         string = f'{self.content},off={self.offset},dur={self.duration}'
+        if self.numNotes != 1:
+            string += f',numNotes={self.numNotes}'
         # and then any style fields
         for k, v in self.styledict.items():
             string += f",{k}={v}"
@@ -323,7 +341,7 @@ class AnnVoice:
                 currently equivalent to AllObjects).
         """
         self.voice = voice.id
-        note_list = M21Utils.get_notes(voice)
+        note_list = M21Utils.get_notes_and_gracenotes(voice)
         if not note_list:
             self.en_beam_list = []
             self.tuplet_list = []
