@@ -407,31 +407,71 @@ class M21Utils:
     @staticmethod
     def get_extras(measure: m21.stream.Measure, spannerBundle: m21.spanner.SpannerBundle) -> List[m21.base.Music21Object]:
         # returns a list of every object contained in the measure (and in the measure's
-        # substreams/Voices), skipping any Streams, GeneralNotes (which are returned from
-        # get_notes/get_notes_and_gracenotes), and Barlines.  We're looking for things
+        # substreams/Voices), skipping any Streams, layout stuff, and GeneralNotes (which
+        # are returned from get_notes/get_notes_and_gracenotes).  We're looking for things
         # like Clefs, TextExpressions, and Dynamics...
         output: List[m21.base.Music21Object] = []
-
-        initialList: List[m21.base.Music21Object] = list(
-            measure.recurse().getElementsNotOfClass(
-                (m21.note.GeneralNote,
-                 m21.stream.Stream,
-                 m21.layout.LayoutBase) ) )
+        initialList: List[m21.base.Music21Object]
+        if hasattr(m21.spanner, 'SpannerAnchor'):
+            initialList = list(
+                measure.recurse().getElementsNotOfClass(
+                    (m21.note.GeneralNote,
+                     m21.spanner.SpannerAnchor,
+                     m21.stream.Stream,
+                     m21.layout.LayoutBase) ) )
+        else:
+            initialList = list(
+                measure.recurse().getElementsNotOfClass(
+                    (m21.note.GeneralNote,
+                     m21.stream.Stream,
+                     m21.layout.LayoutBase) ) )
 
         # loop over the initialList, filtering out (and complaining about) things we
-        # don't recognize.
+        # don't recognize.  Also, we filter out hidden (non-printed) extras.  And
+        # barlines of type 'none' (also not printed).
         for el in initialList:
-            if M21Utils.extra_to_string(el) != '':
-                output.append(el)
+            # we ignore hidden extras
+            if el.hasStyleInformation and el.style.hideObjectOnPrint:
+                continue
+            if isinstance(el, m21.bar.Barline) and el.type == 'none':
+                continue
+            if M21Utils.extra_to_string(el) == '':
+                continue
+            output.append(el)
 
-        # we must add any Crescendo/Diminuendo spanners that start on GeneralNotes in this measure
-        for gn in measure.recurse().getElementsByClass(m21.note.GeneralNote):
-            dwList: List[m21.dynamics.DynamicWedge] = gn.getSpannerSites(m21.dynamics.DynamicWedge)
-            for dw in dwList:
-                if dw not in spannerBundle:
-                    continue
-                if dw.isFirst(gn):
-                    output.append(dw)
+        # Add any ArpeggioMarkSpanners/Crescendos/Diminuendos that start
+        # on GeneralNotes/SpannerAnchors in this measure
+        if hasattr(m21.expressions, 'ArpeggioMarkSpanner'):
+            spanner_types = (m21.expressions.ArpeggioMarkSpanner, m21.dynamics.DynamicWedge)
+        else:
+            spanner_types = (m21.dynamics.DynamicWedge,)
+
+        if hasattr(m21.spanner, 'SpannerAnchor'):
+            for gn in measure.recurse().getElementsByClass(
+                (m21.note.GeneralNote, m21.spanner.SpannerAnchor)
+            ):
+                spannerList: List[m21.spanner.Spanner] = gn.getSpannerSites(spanner_types)
+                for sp in spannerList:
+                    if sp not in spannerBundle:
+                        continue
+                    if sp.isFirst(gn):
+                        output.append(sp)
+        else:
+            for gn in measure.recurse().getElementsByClass(m21.note.GeneralNote):
+                spannerList: List[m21.spanner.Spanner] = gn.getSpannerSites(spanner_types)
+                for sp in spannerList:
+                    if sp not in spannerBundle:
+                        continue
+                    if sp.isFirst(gn):
+                        output.append(sp)
+
+        # Add any RepeatBracket spanners that start on this measure
+        rbList: List[m21.spanner.Spanner] = measure.getSpannerSites(m21.spanner.RepeatBracket)
+        for rb in rbList:
+            if rb not in spannerBundle:
+                continue
+            if rb.isFirst(measure):
+                output.append(rb)
 
         return output
 
@@ -691,6 +731,21 @@ class M21Utils:
             output = 'wedge'
         return f'DY:{output}'
 
+    @staticmethod
+    def arpeggiomark_to_string(
+        arp: m21.expressions.Expression) -> str:
+        if hasattr(m21.expressions, 'ArpeggioMark'):
+            if isinstance(arp, m21.expressions.ArpeggioMark):
+                return f'ARP:{arp.type}'
+        if hasattr(m21.expressions, 'ArpeggioMarkSpanner'):
+            if isinstance(arp, m21.expressions.ArpeggioMarkSpanner):
+                return f'ARPS:{arp.type}:len={len(arp)}'
+        return ''
+
+    @staticmethod
+    def repeatbracket_to_string(rb: m21.spanner.RepeatBracket) -> str:
+        return f'END:{rb.number}:len={len(rb)}'
+
     @staticmethod
     def extra_to_string(extra: m21.base.Music21Object) -> str:
         if isinstance(extra, (m21.key.Key, m21.key.KeySignature)):
@@ -709,8 +764,14 @@ class M21Utils:
             return M21Utils.tempo_to_string(extra)
         if isinstance(extra, m21.bar.Barline):
             return M21Utils.barline_to_string(extra)
+        if isinstance(extra, m21.spanner.RepeatBracket):
+            return M21Utils.repeatbracket_to_string(extra)
+        if (hasattr(m21.expressions, 'ArpeggioMark')
+                and hasattr(m21.expressions, 'ArpeggioMarkSpanner')):
+            if isinstance(extra, (m21.expressions.ArpeggioMark, m21.expressions.ArpeggioMarkSpanner)):
+                return M21Utils.arpeggiomark_to_string(extra)
 
-        print(f'Unexpected extra: {extra.classes[0]}', file=sys.stderr)
+        # print(f'Unexpected extra: {extra.classes[0]}', file=sys.stderr)
         return ''
 
     @staticmethod
